@@ -11,44 +11,17 @@ from .typing import Any, Dict, Iterator, List, MethodType, Optional, ResponseTyp
 
 __all__ = [
     "MockClient",
+    "BaseMockClient",
     "dynamics_cache",
     "dynamics_client",
 ]
 
 
-class MockClient(DynamicsClient):
+class BaseMockClient:
     def __init__(self):
-        r"""A testing client for the Dynamics client.
-
-        -----------------------------------------------------------
-
-        Can be used with `pytest.mark.parametrize`::
-
-            @pytest.mark.parametrize(
-                "dynamics_client",
-                [
-                    MockClient().with_responses({"foo": "bar"}),
-                    MockClient().with_responses({"foo": "baz"}),
-                ],
-                indirect=True,  # important!
-            )
-            def test_foo(dynamics_client):
-                x = dynamics_client.get()
-
-        -----------------------------------------------------------
-
-        Can also be used without `pytest.mark.parametrize`::
-
-            def test_foo(dynamics_client):
-                dynamics_client.with_responses({"foo": "bar"})
-
-                x = dynamics_client.get()
-
-        -----------------------------------------------------------
-        """
-
         with patch("dynamics.client.get_token"):
             super().__init__("", "", "", "", [])
+
         self.__len: int = -1
         self.__default_status: int = 200
         self.__internal: bool = False
@@ -57,7 +30,7 @@ class MockClient(DynamicsClient):
         self.__status_codes: Iterator[int] = _cycle([self.__default_status])
         self.__exceptions: Optional[Iterator[Optional[Exception]]] = None
 
-    def with_responses(self, *responses: ResponseType, cycle: bool = False) -> "MockClient":
+    def with_responses(self, *responses: ResponseType, cycle: bool = False) -> "BaseMockClient":
         """List the responses the client should return, or exceptions it should raise.
         When the client uses one of its HTTP methods (get, post, patch, delete),
         the responses from the list given here are patched to those methods
@@ -74,7 +47,7 @@ class MockClient(DynamicsClient):
     # These are tools for testing internal behaviour
 
     @property
-    def internal(self) -> "MockClient":
+    def internal(self) -> "BaseMockClient":
         """Mock the OAuthSession HTTP methods instead of the Dynamics client ones.
         This allows testing of the internal logic of the client in case, e.g.,
         special error handling has been implemented on a client.
@@ -82,7 +55,7 @@ class MockClient(DynamicsClient):
         self.__internal = True
         return self
 
-    def with_status_codes(self, *status_codes: int, cycle: bool = False) -> "MockClient":
+    def with_status_codes(self, *status_codes: int, cycle: bool = False) -> "BaseMockClient":
         """Not needed if not using the 'dynamics_client.internal'.
 
         List the status codes the OAuthSession should return. When the client uses one of its
@@ -97,7 +70,7 @@ class MockClient(DynamicsClient):
         self.__status_codes = _cycle(status_codes) if cycle else iter(status_codes)
         return self
 
-    def with_exceptions(self, *exceptions: Exception, cycle: bool = False) -> "MockClient":
+    def with_exceptions(self, *exceptions: Exception, cycle: bool = False) -> "BaseMockClient":
         """Not needed if not using the 'dynamics_client.internal'.
 
         List the exceptions the client should raise based on what the OAuthSession returned.
@@ -139,7 +112,7 @@ class MockClient(DynamicsClient):
         """
         return self.__response
 
-    def _check_length(self, length: int) -> "MockClient":
+    def _check_length(self, length: int) -> "BaseMockClient":
         if self.__len != -1 and length != self.__len:
             raise ValueError("Mismaching number of arguments given for MockResponse")
         self.__len = length
@@ -166,28 +139,63 @@ class MockClient(DynamicsClient):
             with patch(f"requests_oauthlib.oauth2_session.OAuth2Session.{method}", side_effect=[response_mock]):
                 yield
         else:
-            with patch(f"dynamics.client.DynamicsClient.{method}", side_effect=[self.__response]):
+
+            client_class = self.__class__.__bases__[-1]
+            class_dot_path = f"{client_class.__module__}.{client_class.__qualname__}"
+
+            with patch(f"{class_dot_path}.{method}", side_effect=[self.__response]):
                 yield
 
     def get(self, not_found_ok: bool = False, next_link: Optional[str] = None, **kwargs) -> List[Dict[str, Any]]:
         with self._mock_method("get"):
-            return super().get(not_found_ok=not_found_ok, next_link=next_link, **kwargs)
+            return super().get(not_found_ok=not_found_ok, next_link=next_link, **kwargs)  # noqa pylint: disable=E1101
 
     def post(self, data: Dict[str, Any], **kwargs) -> Dict[str, Any]:
         with self._mock_method("post"):
-            return super().post(data=data, **kwargs)
+            return super().post(data=data, **kwargs)  # noqa pylint: disable=E1101
 
     def patch(self, data: Dict[str, Any], **kwargs) -> Dict[str, Any]:
         with self._mock_method("patch"):
-            return super().patch(data=data, **kwargs)
+            return super().patch(data=data, **kwargs)  # noqa pylint: disable=E1101
 
     def delete(self, **kwargs) -> None:
         with self._mock_method("delete"):
-            return super().delete(**kwargs)
+            return super().delete(**kwargs)  # noqa pylint: disable=E1101
+
+
+class MockClient(BaseMockClient, DynamicsClient):
+    r"""A testing client for the Dynamics client.
+
+    -----------------------------------------------------------
+
+    Can be used with `pytest.mark.parametrize`::
+
+        @pytest.mark.parametrize(
+            "dynamics_client",
+            [
+                MockClient().with_responses({"foo": "bar"}),
+                MockClient().with_responses({"foo": "baz"}),
+            ],
+            indirect=True,  # important!
+        )
+        def test_foo(dynamics_client):
+            x = dynamics_client.get()
+
+    -----------------------------------------------------------
+
+    Can also be used without `pytest.mark.parametrize`::
+
+        def test_foo(dynamics_client):
+            dynamics_client.with_responses({"foo": "bar"})
+
+            x = dynamics_client.get()
+
+    -----------------------------------------------------------
+    """
 
 
 @pytest.fixture(scope="session")
-def dynamics_cache_constructor():
+def _dynamics_cache_constructor():
     """Imports the django cache instance or creates a SQLiteCache instance."""
     try:
         from django.core.cache import cache  # pylint: disable=C0415,W0621
@@ -200,14 +208,15 @@ def dynamics_cache_constructor():
 
 
 @pytest.fixture()
-def dynamics_cache(dynamics_cache_constructor):  # pylint: disable=W0621
-    """Imports the django cache instance or creates a SQLiteCache instance."""
-    dynamics_cache_constructor.clear()
-    yield dynamics_cache_constructor
+def dynamics_cache(_dynamics_cache_constructor):  # pylint: disable=W0621
+    """Get the session instance of either Django's cache or SQLiteCache."""
+    _dynamics_cache_constructor.clear()
+    yield _dynamics_cache_constructor
 
 
 @pytest.fixture
 def dynamics_client(request) -> MockClient:  # pylint: disable=W0621
+    """Get a mocked client instance, or forward one created in `pytest.mark.parametrize`."""
     if not hasattr(request, "param"):
         yield MockClient()
     else:
